@@ -97,13 +97,12 @@ static HPDriver *Drivers = NULL;
  */
 static void HPDeviceAppeared(void *refCon, io_iterator_t iterator)
 {
-	kern_return_t kret;
 	io_service_t obj;
 
 	(void)refCon;
 
 	while ((obj = IOIteratorNext(iterator)))
-		kret = IOObjectRelease(obj);
+		IOObjectRelease(obj);
 
 	HPScan();
 }
@@ -114,13 +113,12 @@ static void HPDeviceAppeared(void *refCon, io_iterator_t iterator)
  */
 static void HPDeviceDisappeared(void *refCon, io_iterator_t iterator)
 {
-	kern_return_t kret;
 	io_service_t obj;
 
 	(void)refCon;
 
 	while ((obj = IOIteratorNext(iterator)))
-		kret = IOObjectRelease(obj);
+		IOObjectRelease(obj);
 
 	HPScan();
 }
