@@ -76,10 +76,10 @@ static void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
 int main(/*@unused@*/ int argc, /*@unused@*/ char **argv)
 {
 	SCARDHANDLE hCard;
-	SCARDCONTEXT hContext;
+	SCARDCONTEXT hContext = -1;
 	SCARD_READERSTATE rgReaderStates[1];
 	DWORD dwReaderLen, dwState, dwProt, dwAtrLen;
-	DWORD dwPref, dwReaders = 0;
+	DWORD dwPref = -1, dwReaders = 0;
 	char *pcReader = NULL, *mszReaders;
 #ifdef USE_AUTOALLOCATE
 	unsigned char *pbAtr = NULL;
@@ -94,7 +94,7 @@ int main(/*@unused@*/ int argc, /*@unused@*/ char **argv)
 	DWORD dwBufLen;
 	unsigned char *pbAttr = NULL;
 	DWORD pcbAttrLen;
-	char *mszGroups;
+	char *mszGroups = NULL;
 	DWORD dwGroups = 0;
 	long rv;
 	DWORD i;
